@@ -111,8 +111,8 @@ PASSWORD_PARAMETER_NAMES = (
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
 
 # The default version of the Bare metal API to set in overcloudrc.
-# 1.29 is the latest API version in Ironic Ocata supported by ironicclient.
-DEFAULT_BAREMETAL_API_VERSION = '1.29'
+# 1.34 is the latest API version in Ironic Pike supported by ironicclient.
+DEFAULT_BAREMETAL_API_VERSION = '1.34'
 
 # The default version of the Image API to set in overcloudrc.
 DEFAULT_IMAGE_API_VERSION = '2'
@@ -130,3 +130,6 @@ DEFAULT_DEPLOY_RAMDISK_NAME = 'bm-deploy-ramdisk'
 
 # The name for the swift container to host the cache for tripleo
 TRIPLEO_CACHE_CONTAINER = "__cache__"
+
+TRIPLEO_UI_LOG_FILE_SIZE = 1e7  # 10MB
+TRIPLEO_UI_LOG_FILENAME = 'tripleo-ui.logs'
